@@ -3,15 +3,13 @@ from dataclasses import dataclass
 from enum import Enum
 from subprocess import CompletedProcess
 from typing import Any, List, Optional, Tuple, Callable
-import PyInquirer
-from fds.domain.commands import AddCommands
 from fds.domain.constants import MAX_THRESHOLD_SIZE
 from fds.logger import Logger
 from fds.services.pretty_print import PrettyPrint
 from fds.services.types import DvcAdd, InnerService
 from fds.utils import get_size_of_path, convert_bytes_to_readable, convert_bytes_to_string, execute_command, \
     append_line_to_file, check_git_ignore, check_dvc_ignore, does_file_exist, \
-    construct_dvc_url_from_git_url_dagshub, get_input_from_user
+    construct_dvc_url_from_git_url_dagshub, get_input_from_user, get_expand_input_from_user, get_list_choice_from_user
 
 
 # Choices for DVC
@@ -68,9 +66,6 @@ class DVCService(InnerService):
         execute_command(["dvc", "init", "--subdir"])
         return "DVC initialized successfully"
 
-    def is_initialized(self) -> Any:
-        return does_file_exist(f"{self.repo_path}/.dvc")
-
     def status(self) -> Any:
         """
         Responsible for running dvc status
@@ -100,7 +95,7 @@ class DVCService(InnerService):
                 dirs.remove(d)
 
     @staticmethod
-    def _get_choice(file_or_dir_to_check: str, path_size: int, file_dir_type: str) -> dict:
+    def _get_choice(file_or_dir_to_check: str, path_size: int, file_dir_type: str) -> str:
         choices = [{
             "key": "d",
             "name": "Add to DVC",
@@ -125,23 +120,16 @@ class DVCService(InnerService):
                 "value": DvcChoices.STEP_INTO.value
             })
 
-        questions = [
-            {
-                "type": "expand",
-                "message": f"What would you like to do with {file_dir_type} {file_or_dir_to_check} of "
-                           f"{convert_bytes_to_readable(path_size)}?",
-                "name": "selection_choice",
-                "choices": choices,
-                "default": DvcChoices.ADD_TO_DVC.value
-            }
-        ]
-        answers = PyInquirer.prompt(questions)
-        return answers
+        answer = get_expand_input_from_user(f"What would you like to do with {file_dir_type} {file_or_dir_to_check} of "
+                                            f"{convert_bytes_to_readable(path_size)}?", choices, DvcChoices.ADD_TO_DVC.value, False)
+        return answer
 
-    def __get_to_add_to_dvc(self,
-                            file_or_dir_to_check: str,
-                            dirs: List[str],
-                            file_dir_type: str) -> AddToDvc:
+    def __get_to_add_to_dvc(
+        self,
+        file_or_dir_to_check: str,
+        dirs: List[str],
+        file_dir_type: str
+    ) -> AddToDvc:
         """
         Returns the tuple (file/folder to be added to dvc, folder to be ignored)
         :param file_or_dir_to_check: File or folder to check if its to be added or ignored
@@ -164,22 +152,22 @@ class DVCService(InnerService):
             if self.selection_message_count == 0:
                 self.selection_message_count = 1
                 self.printer.warn('========== Make your selection, Press "h" for help ==========')
-            answers = DVCService._get_choice(file_or_dir_to_check=file_or_dir_to_check,
-                                             path_size=path_size,
-                                             file_dir_type=file_dir_type)
-            if answers["selection_choice"] == DvcChoices.ADD_TO_DVC.value:
+            answer = DVCService._get_choice(file_or_dir_to_check=file_or_dir_to_check,
+                                            path_size=path_size,
+                                            file_dir_type=file_dir_type)
+            if answer == DvcChoices.ADD_TO_DVC.value:
                 # Dont need to traverse deep
                 [dirs.remove(d) for d in list(dirs)]
                 return AddToDvc(file_or_dir_to_check, None, None)
-            elif answers["selection_choice"] == DvcChoices.ADD_TO_GIT.value:
+            elif answer == DvcChoices.ADD_TO_GIT.value:
                 # Dont need to traverse deep
                 [dirs.remove(d) for d in list(dirs)]
                 return AddToDvc(None, None, None)
-            elif answers["selection_choice"] == DvcChoices.SKIP.value:
+            elif answer == DvcChoices.SKIP.value:
                 # Dont need to traverse deep as we are skipping the folder/file
                 [dirs.remove(d) for d in list(dirs)]
                 return AddToDvc(None, None, file_or_dir_to_check)
-            elif answers["selection_choice"] == DvcChoices.IGNORE.value:
+            elif answer == DvcChoices.IGNORE.value:
                 # We should ignore the ./ in beginning when adding to gitignore
                 # Add files to gitignore
                 append_line_to_file(".gitignore",
@@ -329,16 +317,8 @@ class DVCService(InnerService):
     def _show_choice_of_remotes(remotes: dict) -> str:
         choices = list(remotes.keys())
         choices.append("Cancel Pull")
-        questions = [
-            {
-                'type': 'list',
-                'name': 'remote',
-                'message': 'Choose the remote to use for pulling dvc repo?',
-                'choices': choices
-            }
-        ]
-        answers = PyInquirer.prompt(questions)
-        return answers["remote"]
+        answer = get_list_choice_from_user('Choose the remote to use for pulling dvc repo?', choices)
+        return answer
 
     def pull(self, git_url: str, remote_name: Optional[str]) -> Any:
         """
