@@ -17,7 +17,7 @@ class TestRun(IntegrationTestCase):
         self.run({"command": Commands.INIT.value}).execute()
         self.run({"command": Commands.STATUS.value}).execute()
 
-    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.ADD_TO_DVC.value})
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value=DvcChoices.ADD_TO_DVC.value)
     def test_add(self, get_choice):
         self.run({"command": Commands.INIT.value}).execute()
         super().create_fake_git_data()
@@ -34,7 +34,7 @@ class TestRun(IntegrationTestCase):
         assert "new file:   git_data/file-3" in convert_bytes_to_string(output.stdout)
         assert "new file:   git_data/file-4" in convert_bytes_to_string(output.stdout)
 
-    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.ADD_TO_DVC.value})
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value=DvcChoices.ADD_TO_DVC.value)
     def test_add_multiple_paths(self, get_choice):
         self.run({"command": Commands.INIT.value}).execute()
         super().create_fake_git_data()
@@ -48,7 +48,7 @@ class TestRun(IntegrationTestCase):
         assert "new file:   large_file_1.dvc" in convert_bytes_to_string(output.stdout)
         assert "\n\tlarge_file_2" in convert_bytes_to_string(output.stdout)
 
-    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.IGNORE.value})
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value=DvcChoices.IGNORE.value)
     def test_add_dvc_ignore(self, get_choice):
         self.run({"command": Commands.INIT.value}).execute()
         super().create_fake_git_data()
@@ -57,7 +57,7 @@ class TestRun(IntegrationTestCase):
         output = execute_command(["cat", ".dvcignore"], capture_output=True)
         assert "large_file" in convert_bytes_to_string(output.stdout)
 
-    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.ADD_TO_DVC.value})
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value=DvcChoices.ADD_TO_DVC.value)
     def test_commit(self, get_choice):
         self.run({"command": Commands.INIT.value}).execute()
         super().create_fake_git_data()
@@ -75,7 +75,7 @@ class TestRun(IntegrationTestCase):
         output = execute_command(["git", "diff", "--raw", "HEAD~1"], capture_output=True)
         assert "large_file.dvc" in convert_bytes_to_string(output.stdout)
 
-    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.SKIP.value})
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value=DvcChoices.SKIP.value)
     def test_skip_in_add(self, get_choice):
         self.run({"command": Commands.INIT.value}).execute()
         super().create_fake_git_data()
